@@ -970,8 +970,7 @@ if (!window.Picasso.hasOwnProperty("Dialog")) {
         /* Sanity check for reseller and org admins */
         if (!account.is(Picasso.Account.Flags.ADMIN) && (
             account.is(Picasso.Account.Flags.ORG_CREATOR) ||
-            account.is(Picasso.Account.Flags.ORG_ADMIN)))
-        {
+            account.is(Picasso.Account.Flags.ORG_ADMIN))) {
             if (0 === items.length || !isMemberOfAnyOrg) {
                 Picasso.Notification.show(Picasso.Lang.get(
                     "notification_error_must_be_member_of_any_org"), "warning");
@@ -984,239 +983,261 @@ if (!window.Picasso.hasOwnProperty("Dialog")) {
             }
         }
 
-        /**
-         * WARNING: Apparently, we cannot start all these async requests
-         *          at once, because some synchronizing timing issue
-         *          raises database exceptions.
-         *
-         *          So we basically wrap all requests in functions (to prevent
-         *          starting them immediately) and chain them with promises..
-         **/
+        var usedQuota = dialog._account.getQuotaUsed();
+        var newQuota = dialog._account.getQuotaTotal();
 
-        /* Store data */
-        var defer_save = function () {
-            return dialog._account.save(null,
-
-                /* Error */
-                function (e, status) {
-                    /* Handle account errors */
-                    switch (status) {
-                        case 405:
-                            Picasso.Notification.show(
-                                Picasso.Lang.get(
-                                    "notification_error_cannot_set_expiration_date"));
-                            break;
-                        case 406:
-                            Picasso.Helper.updatePasswordPolicy();
-
-                            Picasso.Notification.show(
-                                Picasso.Lang.get(
-                                    "notification_error_password_policy_mismatch"));
-                            break;
-
-                        case 409:
-                            Picasso.Notification.show(Picasso.Lang.get(
-                                "notification_error_duplicate",
-                                Picasso.Lang.get("label_accounts")), "warning");
-                            break;
-                        case 417:
-                            Picasso.Notification.show(
-                                    Picasso.Lang.get(
-                                            "notification_error_cannot_set_decrease_storage"));
-                            break;
-                        default:
-                            Picasso.Dialog.handleOrgErrors(status);
-                    }
-
-                    if (onError) {
-                        onError(e, status);
-                    }
-                }
+        if (newQuota > 0 && newQuota < usedQuota) {
+            var confirmDialog = new Picasso.Dialog(
+                "#pica_confirmation_dialog",
+                Picasso.Lang.get("dialog_title_storage_warning"),
+                Picasso.Lang.get("dialog_body_storage_update_warning",
+                    Picasso.Helper.formatSize(newQuota),
+                    Picasso.Helper.formatSize(usedQuota)
+                )
             );
-        };
 
-        /* Store mails */
-        var mails = dialog._mails_inputList.getItems();
-
-        var defer_mails = function () {
-            return dialog._account.setEmails($.map(mails, function (val) {
-                return val.name
-            }))
-        };
-
-        /* Store folders */
-        var folders = dialog._folders_inputList.getItems();
-
-        dialog._account._folderscount = folders.length;
-
-        var defer_folders = function () {
-            var data= {
-                "folders" : []
-            }
-
-            /* Collect data */
-            $.each(folders, function () {
-                var folder ={}
-                if (this.hasOwnProperty("oid") && this.oid) {
-                    folder["folderID"] = (this.oid);
-                } else if (this.hasOwnProperty("name") && this.name) {
-                    folder["folderName"] = (this.name);
-                }
-                folder["permission"] = Picasso.Permission.toString(this.permission);
-                data["folders"].push(folder);
+            confirmDialog.setOkHandler(function () {
+                confirmDialog.hide();
+                runSaveChain();
             });
 
-            return dialog._account.setFolders(data, null,
+            confirmDialog.setCancelHandler(function () {
+                $("#pica_account_dialog").find(".modal-footer button[data-dismiss].btn-primary .pica-spinner").remove();
 
-                /* Error */
-                function (e, status) {
-                    /* Handle folder errors */
-                    switch (status) {
-                        case 409:
-                            Picasso.Notification.show(Picasso.Lang.get(
-                                "notification_error_duplicate",
-                                Picasso.Lang.get("label_folders")), "warning");
-                            break;
-                    }
-
-                    if (onError) {
-                        onError(e, status);
-                    }
-                }
-            );
-        };
-
-        /* Store groups */
-        var groups = dialog._groups_inputList.getItems();
-
-        dialog._account._groupscount = groups.length;
-
-        var defer_groups = function () {
-            var data = {
-                "groupID[]": [],
-                "groupName[]": [],
-                "isGroupAdmin[]": []
-            };
-
-            /* Collect data */
-            $.each(groups, function () {
-                if (this.hasOwnProperty("oid") && this.oid) {
-                    data["groupID[]"].push(this.oid);
-                } else {
-                    data["groupName[]"].push(this.name);
-                }
-
-                data["isGroupAdmin[]"].push((this.isGroupAdmin || false));
             });
 
-            return dialog._account.setGroups(data, null, onError);
-        };
+            confirmDialog.show();
+            return;
+        }
 
-        /* Store organizations */
-        var organizations = dialog._organizations_inputList.getItems();
+        runSaveChain();
 
-        var defer_organizations = function () {
-            var data = {
-                "organizationID[]": [],
-                "isMember[]": [],
-                "isOrgAdmin[]": [],
-                "organizationNames[]":[]
-            };
+        function runSaveChain() {
+            /**
+             * WARNING: Apparently, we cannot start all these async requests
+             *          at once, because some synchronizing timing issue
+             *          raises database exceptions.
+             *
+             *          So we basically wrap all requests in functions (to prevent
+             *          starting them immediately) and chain them with promises..
+             **/
 
-            /* Collect data */
-            $.each(organizations, function () {
-                if (this.hasOwnProperty("oid") && this.oid) {
-                    data["organizationID[]"].push(this.oid);
-                }
-                else{
-                    //new org to be created
-                    data["organizationID[]"].push("new");
-
-                }
-
-                data["organizationNames[]"].push((this.name));
-                data["isMember[]"].push((this.isMember || false));
-                data["isOrgAdmin[]"].push((this.isOrgAdmin || false));
-
-                /* Check if we have to update the organization of the account */
-                if (this.isMember) {
-                    dialog._account.setOrgOid(this.oid);
-                } else if (dialog._account.getOrgOid() === this.oid) {
-                    dialog._account.setOrgOid(null);
-                }
-            });
-
-            return dialog._account.setOrganizations(data, null,
-
-                /* Error */
-                function (e, status) {
-                    Picasso.Dialog.handleOrgErrors(status);
-
-                    if (onError) {
-                        onError(e, status);
-                    }
-                }
-            )
-        };
-
-        var defer_customer = function (){
-            if (dialog._account.is(Picasso.Account.Flags.ORG_CREATOR)) {
-                var customer = Picasso.get("customer");
-                if (!customer) {
-                    var customer = new Picasso.Customer();
-                }
-                var accountOID = dialog._account.getOid();
-                assignCustomerData(accountOID, customer);
-                customer.setCustomer(
-                    /* Success */
-                    function (data, status) {
-
-                        switch (status) {
-                            case 200:
-                                Picasso.Notification.show(Picasso.Lang.get("notification_stripe_customer_updated"),"info");
-                                break;
-                            case 201:
-                                Picasso.Notification.show(Picasso.Lang.get("notification_stripe_customer_updated"),"info");
-                                break
-                        }
-
-                    },
+            /* Store data */
+            var defer_save = function () {
+                return dialog._account.save(null,
 
                     /* Error */
-                    function (data, status) {
+                    function (e, status) {
+                        /* Handle account errors */
                         switch (status) {
-                            case 420:
-                                Picasso.Notification.show(Picasso.Lang.get("notification_stripe_customer_update_failed"),"danger");
-                                break
-                            case 424:
-                                Picasso.Notification.show(Picasso.Lang.get("notification_stripe_customer_update_failed"),"danger");
-                                break
+                            case 405:
+                                Picasso.Notification.show(
+                                    Picasso.Lang.get(
+                                        "notification_error_cannot_set_expiration_date"));
+                                break;
+                            case 406:
+                                Picasso.Helper.updatePasswordPolicy();
+
+                                Picasso.Notification.show(
+                                    Picasso.Lang.get(
+                                        "notification_error_password_policy_mismatch"));
+                                break;
+
+                            case 409:
+                                Picasso.Notification.show(Picasso.Lang.get(
+                                    "notification_error_duplicate",
+                                    Picasso.Lang.get("label_accounts")), "warning");
+                                break;
+                            default:
+                                Picasso.Dialog.handleOrgErrors(status);
+                        }
+
+                        if (onError) {
+                            onError(e, status);
                         }
                     }
                 );
+            };
+
+            /* Store mails */
+            var mails = dialog._mails_inputList.getItems();
+
+            var defer_mails = function () {
+                return dialog._account.setEmails($.map(mails, function (val) {
+                    return val.name
+                }))
+            };
+
+            /* Store folders */
+            var folders = dialog._folders_inputList.getItems();
+
+            dialog._account._folderscount = folders.length;
+
+            var defer_folders = function () {
+                var data = {
+                    "folders": []
+                }
+
+                /* Collect data */
+                $.each(folders, function () {
+                    var folder = {}
+                    if (this.hasOwnProperty("oid") && this.oid) {
+                        folder["folderID"] = (this.oid);
+                    } else if (this.hasOwnProperty("name") && this.name) {
+                        folder["folderName"] = (this.name);
+                    }
+                    folder["permission"] = Picasso.Permission.toString(this.permission);
+                    data["folders"].push(folder);
+                });
+
+                return dialog._account.setFolders(data, null,
+
+                    /* Error */
+                    function (e, status) {
+                        /* Handle folder errors */
+                        switch (status) {
+                            case 409:
+                                Picasso.Notification.show(Picasso.Lang.get(
+                                    "notification_error_duplicate",
+                                    Picasso.Lang.get("label_folders")), "warning");
+                                break;
+                        }
+
+                        if (onError) {
+                            onError(e, status);
+                        }
+                    }
+                );
+            };
+
+            /* Store groups */
+            var groups = dialog._groups_inputList.getItems();
+
+            dialog._account._groupscount = groups.length;
+
+            var defer_groups = function () {
+                var data = {
+                    "groupID[]": [],
+                    "groupName[]": [],
+                    "isGroupAdmin[]": []
+                };
+
+                /* Collect data */
+                $.each(groups, function () {
+                    if (this.hasOwnProperty("oid") && this.oid) {
+                        data["groupID[]"].push(this.oid);
+                    } else {
+                        data["groupName[]"].push(this.name);
+                    }
+
+                    data["isGroupAdmin[]"].push((this.isGroupAdmin || false));
+                });
+
+                return dialog._account.setGroups(data, null, onError);
+            };
+
+            /* Store organizations */
+            var organizations = dialog._organizations_inputList.getItems();
+
+            var defer_organizations = function () {
+                var data = {
+                    "organizationID[]": [],
+                    "isMember[]": [],
+                    "isOrgAdmin[]": [],
+                    "organizationNames[]": []
+                };
+
+                /* Collect data */
+                $.each(organizations, function () {
+                    if (this.hasOwnProperty("oid") && this.oid) {
+                        data["organizationID[]"].push(this.oid);
+                    } else {
+                        //new org to be created
+                        data["organizationID[]"].push("new");
+
+                    }
+
+                    data["organizationNames[]"].push((this.name));
+                    data["isMember[]"].push((this.isMember || false));
+                    data["isOrgAdmin[]"].push((this.isOrgAdmin || false));
+
+                    /* Check if we have to update the organization of the account */
+                    if (this.isMember) {
+                        dialog._account.setOrgOid(this.oid);
+                    } else if (dialog._account.getOrgOid() === this.oid) {
+                        dialog._account.setOrgOid(null);
+                    }
+                });
+
+                return dialog._account.setOrganizations(data, null,
+
+                    /* Error */
+                    function (e, status) {
+                        Picasso.Dialog.handleOrgErrors(status);
+
+                        if (onError) {
+                            onError(e, status);
+                        }
+                    }
+                )
+            };
+
+            var defer_customer = function () {
+                if (dialog._account.is(Picasso.Account.Flags.ORG_CREATOR)) {
+                    var customer = Picasso.get("customer");
+                    if (!customer) {
+                        customer = new Picasso.Customer();
+                    }
+                    var accountOID = dialog._account.getOid();
+                    assignCustomerData(accountOID, customer);
+                    customer.setCustomer(
+                        /* Success */
+                        function (data, status) {
+
+                            switch (status) {
+                                case 200:
+                                    Picasso.Notification.show(Picasso.Lang.get("notification_stripe_customer_updated"), "info");
+                                    break;
+                                case 201:
+                                    Picasso.Notification.show(Picasso.Lang.get("notification_stripe_customer_updated"), "info");
+                                    break
+                            }
+
+                        },
+
+                        /* Error */
+                        function (data, status) {
+                            switch (status) {
+                                case 420:
+                                    Picasso.Notification.show(Picasso.Lang.get("notification_stripe_customer_update_failed"), "danger");
+                                    break
+                                case 424:
+                                    Picasso.Notification.show(Picasso.Lang.get("notification_stripe_customer_update_failed"), "danger");
+                                    break
+                            }
+                        }
+                    );
+                }
             }
-        }
 
 
-
-
-
-        /* Future and broken promises */
-        $.when(defer_save()).then(function () {
-            $.when(defer_mails()).then(function () {
-                $.when(defer_folders()).then(function () {
-                    $.when(defer_groups()).then(function () {
-                        $.when(defer_organizations()).then(function () {
-                            $.when(defer_customer()).then(function () {
-                                if (onSuccess) {
-                                    onSuccess(dialog._account);
-                                }
+            /* Future and broken promises */
+            $.when(defer_save()).then(function () {
+                $.when(defer_mails()).then(function () {
+                    $.when(defer_folders()).then(function () {
+                        $.when(defer_groups()).then(function () {
+                            $.when(defer_organizations()).then(function () {
+                                $.when(defer_customer()).then(function () {
+                                    if (onSuccess) {
+                                        onSuccess(dialog._account);
+                                    }
+                                }, onError)
                             }, onError)
                         }, onError)
                     }, onError)
                 }, onError)
-            }, onError)
-        });
+            });
+        };
     };
 
     /**
