@@ -1876,31 +1876,31 @@ if (!window.Picasso.hasOwnProperty("Helper")) {
         var now = new Date();
         var future = (now < moddate);
         var diff = ((now.getTime() - moddate.getTime()) / 1000);
-        var day_diff = Math.floor(diff / 86400);
+        var absSec = Math.abs(diff);
+        var day_diff = Math.round(absSec / 86400);
 
         if (isNaN(day_diff) || 31 < day_diff) {
             return Picasso.Helper.formatDate(date);
         }
 
-        if (future) {
-            day_diff *= -1;
+        if (day_diff === 0) {
+            if (absSec < 60) {
+                return Picasso.Lang.get("age_now");
+            } else if (absSec < 3600) {
+                return Picasso.Lang.get(Picasso.Lang.Flags.INFLECT, future? "age_in_mins" : "age_mins_ago", Math.round(absSec / 60));
+            } else if (absSec < 86400) {
+                return Picasso.Lang.get(Picasso.Lang.Flags.INFLECT, future? "age_in_hours": "age_hours_ago", Math.round(absSec / 3600));
+            }
+        } else if (day_diff === 1) {
+            return Picasso.Lang.get(future ? "age_tomorrow" : "age_yesterday");
+        } else if (day_diff < 7) {
+            return Picasso.Lang.get(Picasso.Lang.Flags.INFLECT, future ? "age_in_days" : "age_days_ago", day_diff);
+        } else {
+            return Picasso.Lang.get(Picasso.Lang.Flags.INFLECT, future ? "age_in_weeks" : "age_weeks_ago", Math.ceil(day_diff / 7));
         }
-
-        return (day_diff === 0 &&
-            (60 > diff && Picasso.Lang.get("age_now") ||
-                3600 > diff && Picasso.Lang.get(
-                    Picasso.Lang.Flags.INFLECT, "age_mins_ago", Math.floor(diff / 60)) ||
-                86400 > diff && Picasso.Lang.get(
-                    Picasso.Lang.Flags.INFLECT, "age_hours_ago", Math.floor(diff / 3600)))) ||
-
-            1 === day_diff && Picasso.Lang.get(
-                (future ? "age_tomorrow" : "age_yesterday")) ||
-            7 > day_diff && Picasso.Lang.get(Picasso.Lang.Flags.INFLECT,
-                (future ? "age_in_days" : "age_days_ago"), day_diff) ||
-            Picasso.Lang.get(Picasso.Lang.Flags.INFLECT,
-                (future ? "age_in_weeks" : "age_weeks_ago"), Math.ceil(day_diff / 7));
     };
 
+
     /**
      * Convert date to human readable string
      *
@@ -1958,7 +1958,7 @@ if (!window.Picasso.hasOwnProperty("Helper")) {
 
     Picasso.Helper.formatJSONDate = function (date) {
         var d = new Date(date);
-        return d.toJSON();
+        return moment(d).format();
     };
 
 
