@@ -203,8 +203,12 @@ if (!window.Picasso.hasOwnProperty("Files")) {
 
         dialog.setOkHandler(function (inputs) {
             var baseName = inputs.pica_input_text.val();
-            var ext = inputs.pica_input_text.data("original-extension") || "";
-            var newName = baseName + ext;
+            var newName = baseName;
+            if (file.is(Picasso.File.Flags.FILE)) {
+                baseName = baseName.replace(/\.[^/.]+$/, "");
+                var ext = inputs.pica_input_text.data("original-extension") || "";
+                newName = baseName + ext;
+            }
             file.rename(newName,
 
                 /* Success */
@@ -244,6 +248,7 @@ if (!window.Picasso.hasOwnProperty("Files")) {
                             Picasso.Notification.show(
                                 Picasso.Lang.get("notification_error_duplicate", name),
                                 "warning");
+                            break;
 
                         case 400:
                             /* Falls through */
@@ -1705,8 +1710,13 @@ if (!window.Picasso.hasOwnProperty("Files")) {
 
         dialog.setOkHandler(function (inputs) {
             var baseName = inputs.pica_input_text.val();
-            var ext = inputs.pica_input_text.data("original-extension") || "";
-            var newName = baseName + ext;
+            var newName = baseName;
+            if (file.is(Picasso.File.Flags.FILE)) {
+                baseName = baseName.replace(/\.[^/.]+$/, "");
+                var ext = inputs.pica_input_text.data("original-extension") || "";
+                newName = baseName + ext;
+            }
+
             var cwd = Picasso.get("cwd");
 
             file.move(cwd, newName,
@@ -2394,10 +2404,6 @@ if (!window.Picasso.hasOwnProperty("Files")) {
 
                 var selectedFile = file;
 
-                if (selectedFile.getIsBlocked()){
-                    containsBlockedFolder = true;
-                }
-
                 if (selectedFile) {
                     var permission = selectedFile.getPermission();
 
