@@ -1271,6 +1271,23 @@ if (!window.Picasso.hasOwnProperty("Profile")) {
             Picasso.Notification.show(
                 Picasso.Lang.get("notification_warning_admin_without_mfa"), "warning");
         }
+
+        if (urlParams.has('invoicesDue') && urlParams.get('invoicesDue') === 'true') {
+            const dialog = new Picasso.Dialog("#pica_confirmation_dialog",
+                Picasso.Lang.get("dialog_title_invoices_due"),
+                Picasso.Lang.get("dialog_body_invoices_due"),
+                Picasso.Dialog.Flags.NO_AUTOCLOSE);
+
+            // Hide the Cancel button before showing the dialog
+            $("#pica_confirmation_dialog .btn-default").hide();
+
+            dialog.setOkHandler(function () {
+                window.location = '/wapi/customers?action=redirectToPortalSession&CSRFToken=' + Picasso.get("CSRF");
+            });
+
+            dialog.show();
+        }
+
     });
 
 
